netapp_ontap.resources.audit_log_redirect API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.audit_log_redirect`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

Use this API to specify a dedicated SVM for all NAS auditing events log to reside in.

## Examples

### Creating an Audit Log Redirect configuration.

To create an Audit Log Redirect configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import AuditLogRedirect

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = AuditLogRedirect()
        resource.svm.uuid = "02c9e252-41be-11e9-81d5-00a0986138f7"
        resource.post(hydrate=True, return_timeout=5, return_records=False)
        print(resource)

### Retrieving an Audit Log Redirect configuration in the cluster.

To retrieve an Audit Log Redirect configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import AuditLogRedirect

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = AuditLogRedirect()
        resource.get()
        print(resource)

Try it out

    AuditLogRedirect(
        {"svm": {"name": "vs2", "uuid": "24870c49-8a73-11ea-ad05-005056827898"}}
    )

### Updating Audit Log Redirect configuration in the cluster.

To modify an existing Audit Log Redirect configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import AuditLogRedirect

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = AuditLogRedirect()
        resource.svm.name = "svm1"
        resource.svm.uuid = "02c9e252-41be-11e9-81d5-00a0986138f7"
        resource.patch()

### Deleting an Audit Log Redirect configuration in the cluster.

To delete an existing Audit Log Redirect configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import AuditLogRedirect

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = AuditLogRedirect()
        resource.delete()

## Classes

`class AuditLogRedirect (*args, **kwargs)`

  Allows interaction with AuditLogRedirect objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes an Audit Log Redirect configuration.

    ### Related ONTAP commands

    - `vserver audit audit-log-redirect delete`

    ### Learn more

    - `DOC /private/protocols/audit/audit-log-redirect`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves Audit Log Redirect configuration.

    ### Related ONTAP commands

    - `vserver audit audit-log-redirect show`

    ### Learn more

    - `DOC /private/protocols/audit/audit-log-redirect`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates an Audit Log Redirect configuration.

    ### Required properties

    - `svm.uuid` or `svm.name` - Existing SVM to which NAS audit events logs will be redirected to.

    ### Related ONTAP commands

    - `vserver audit audit-log-redirect modify`

    ### Learn more

    - `DOC /private/protocols/audit/audit-log-redirect`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Creates an Audit Log Redirect configuration.

    ### Required properties

    - `svm.uuid` or `svm.name` - Existing SVM to which NAS audit events logs will be redirected to.

    ### Related ONTAP commands

    - `vserver audit audit-log-redirect create`

    ### Learn more

    - `DOC /private/protocols/audit/audit-log-redirect`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class AuditLogRedirectSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the AuditLogRedirect object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `links GET`

    The links field of the audit_log_redirect.

  `svm GET POST PATCH`

    The svm field of the audit_log_redirect.